==> lxqt-runner_0.16.0.orig.tar.xz: lxqt-runner-0.16.0/translations/lxqt-runner_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Ustawienia Runnera</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Pokaż na:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Pokaż historię na początku</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Przechowuj/wyświetlaj historię</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Informacja&lt;/b&gt;: Rozmiar najwyżej umieszczonych widżetów może wynosić maksymalnie ⅔ wysokości i szerokości pulpitu.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Liczba wyświetlanych elementów:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Górna krawędź ekranu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Środek ekranu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Używany ekran</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Zawsze na ekranie %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Przywróć</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Wyzwalacz programu </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="370"/>
        <source>Show/hide runner dialog</source>
        <translation>Pokaż/ukryj okno programu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="845"/>
        <source>Mathematics</source>
        <translation>Matematyka</translation>
    </message>
</context>
</TS>

==> lxqt-runner_0.17.0.orig.tar.xz: lxqt-runner-0.17.0/translations/lxqt-runner_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Ustawienia Runnera</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Pokaż na:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Pokaż historię na początku</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Przechowuj/wyświetlaj historię</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Informacja&lt;/b&gt;: Rozmiar najwyżej umieszczonych widżetów może wynosić maksymalnie ⅔ wysokości i szerokości pulpitu.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Liczba wyświetlanych elementów:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Górna krawędź ekranu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Środek ekranu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Używany ekran</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Zawsze na ekranie %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Przywróć</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Wyzwalacz programu </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="370"/>
        <source>Show/hide runner dialog</source>
        <translation>Pokaż/ukryj okno programu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
